aboutsummaryrefslogtreecommitdiffstats
path: root/android
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2014-03-01 08:52:28 +0100
committerMax Kellermann <max@duempel.org>2014-03-01 08:52:28 +0100
commitb2c523e56d134eebe2dfe92aa9ed64bb300eb4a4 (patch)
treef692541fd7f795b68090b82e3819af5c7f7cb9db /android
parent5bc5abf0e739e3637557b336bb91db4c5d986b55 (diff)
downloadmpd-b2c523e56d134eebe2dfe92aa9ed64bb300eb4a4.tar.gz
mpd-b2c523e56d134eebe2dfe92aa9ed64bb300eb4a4.tar.xz
mpd-b2c523e56d134eebe2dfe92aa9ed64bb300eb4a4.zip
android: use "strip" from the Android NDK
Diffstat (limited to 'android')
-rwxr-xr-xandroid/build.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/android/build.py b/android/build.py
index 3dbbc4bda..a0a464630 100755
--- a/android/build.py
+++ b/android/build.py
@@ -59,7 +59,7 @@ target_root = os.path.join(ndk_platform_path, 'arch-' + ndk_arch)
llvm_triple = 'armv7-none-linux-androideabi'
def select_toolchain(use_cxx, use_clang):
global cc, cxx, ar, cflags, cxxflags, cppflags, ldflags, libs
target_arch = '-march=armv7-a -mfloat-abi=softfp'
if use_clang:
@@ -70,6 +70,7 @@ def select_toolchain(use_cxx, use_clang):
cc = os.path.join(gcc_toolchain, 'bin', host_arch + '-gcc')
cxx = os.path.join(gcc_toolchain, 'bin', host_arch + '-g++')
ar = os.path.join(gcc_toolchain, 'bin', host_arch + '-ar')
+ strip = os.path.join(gcc_toolchain, 'bin', host_arch + '-strip')
libstdcxx_path = os.path.join(ndk_path, 'sources/cxx-stl/gnu-libstdc++', gcc_version)
libstdcxx_cppflags = '-isystem ' + os.path.join(libstdcxx_path, 'include') + ' -isystem ' + os.path.join(libstdcxx_path, 'libs', android_abi, 'include')
@@ -217,6 +218,7 @@ class AutotoolsProject(Project):
'LDFLAGS=' + ldflags,
'LIBS=' + libs,
'AR=' + ar,
+ 'STRIP=' + strip,
'--host=' + host_arch,
'--prefix=' + root_path,
'--with-sysroot=' + target_root,
@@ -311,6 +313,7 @@ configure = [
'LDFLAGS=' + ldflags,
'LIBS=' + libs,
'AR=' + ar,
+ 'STRIP=' + strip,
'--host=' + host_arch,
'--prefix=' + root_path,
'--with-sysroot=' + target_root,
@@ -59,7 +59,7 @@ target_root = os.path.join(ndk_platform_path, 'arch-' + ndk_arch)
llvm_triple = 'armv7-none-linux-androideabi'
def select_toolchain(use_cxx, use_clang):
- global cc, cxx, ar, cflags, cxxflags, cppflags, ldflags, libs
+ global cc, cxx, ar, strip, cflags, cxxflags, cppflags, ldflags, libs
target_arch = '-march=armv7-a -mfloat-abi=softfp'
if use_clang: